/*
 * SPDX-FileCopyrightText: Stone Tickle <lattis@mochiro.moe>
 * SPDX-License-Identifier: GPL-3.0-only
 */

#ifndef MUON_FUNCTIONS_MESON_H
#define MUON_FUNCTIONS_MESON_H
#include "lang/func_lookup.h"

extern const struct func_impl impl_tbl_meson[];
extern const struct func_impl impl_tbl_meson_internal[];
#endif
